import { Input, Directive, Renderer2, ElementRef, ViewContainerRef, NgModule } from '@angular/core';
import { PlaceholderDirective, TextDirective } from '@rxweb/localization';

class BaseDirective {
    constructor(renderer, elementRef, viewContainerRef) {
        this.renderer = renderer;
        this.elementRef = elementRef;
        this.viewContainerRef = viewContainerRef;
        this._componentId = null;
        this.element = this.elementRef.nativeElement;
        this.element['isPopulated'] = false;
    }
    set componentId(value) {
        this._componentId = value;
    }
    get component() {
        if (this._componentId == null && this.viewContainerRef && this.viewContainerRef["_view"] && this.viewContainerRef["_view"].component)
            return this.viewContainerRef["_view"].component.constructor;
        return this._componentId;
    }
}
BaseDirective.propDecorators = {
    componentId: [{ type: Input }]
};

class RxPlaceholderDirective extends BaseDirective {
    constructor(renderer, elementRef, viewContainerRef) {
        super(renderer, elementRef, viewContainerRef);
    }
    ngAfterViewInit() {
        if (this.component == null) {
            var componentViewIndex = -1;
            var component = null;
            var element = this.element;
            var FindTry = 1;
            var componentId = this.elementRef.nativeElement.getAttribute('component-id');
            if (componentId == null || componentId == '') {
                componentId = this.name.split('_')[0];
            }
            componentViewIndex = -1;
            if (componentId != null && componentId != '') {
                this.elementRef.nativeElement.__ngContext__.forEach((x, i) => { if (x != null) {
                    if (x.constructor.name.indexOf("LComponentView_" + componentId) > -1) {
                        componentViewIndex = i;
                    }
                } });
                if (componentViewIndex != -1) {
                    var componentIndex = -1;
                    this.elementRef.nativeElement.__ngContext__[componentViewIndex].forEach((x, i) => {
                        if (x != null) {
                            if (x.constructor.name == componentId) {
                                componentIndex = i;
                            }
                        }
                    });
                    if (componentIndex != -1)
                        component = this.elementRef.nativeElement.__ngContext__[componentViewIndex][componentIndex];
                }
            }
            if (component != null && !this.element.isPopulated)
                this.placeholderDirective = new PlaceholderDirective(this.element, this.name, component != null ? component.constructor : null);
            else if (this.element) {
                while (component == null) {
                    componentViewIndex = -1;
                    if (element && element.parentElement && element.parentElement.__ngContext__) {
                        element.parentElement.__ngContext__.forEach((x, i) => { if (x != null) {
                            if (x.constructor.name.indexOf("LComponentView_") > -1) {
                                componentViewIndex = i;
                            }
                        } });
                        var component = null;
                        if (componentViewIndex != -1) {
                            element.parentElement.__ngContext__[componentViewIndex][0].__ngContext__.forEach(x => {
                                for (var item in x) {
                                    if (item == 'components') {
                                        if (x[item].constructor.name == 'Array') {
                                            component = x[item][0];
                                        }
                                    }
                                }
                            });
                        }
                    }
                    if (component == null) {
                        element = element ? element.parentElement : null;
                        FindTry = FindTry + 1;
                    }
                    if (FindTry > 20)
                        break;
                }
                if (!this.element.isPopulated)
                    this.placeholderDirective = new PlaceholderDirective(this.element, this.name, component != null ? component.constructor : null);
            }
        }
        else {
            if (!this.element.isPopulated) {
                this.placeholderDirective = new PlaceholderDirective(this.element, this.name, this.component);
            }
        }
        if (!this.element.isPopulated)
            this.placeholderDirective.bind();
    }
    ngOnDestroy() {
        this.placeholderDirective.destroy();
    }
}
RxPlaceholderDirective.decorators = [
    { type: Directive, args: [{
                selector: '[rxPlaceholder]',
            },] }
];
RxPlaceholderDirective.ctorParameters = () => [
    { type: Renderer2 },
    { type: ElementRef },
    { type: ViewContainerRef }
];
RxPlaceholderDirective.propDecorators = {
    name: [{ type: Input, args: ['rxPlaceholder',] }]
};

class RxTextDirective extends BaseDirective {
    constructor(renderer, elementRef, viewContainerRef) {
        super(renderer, elementRef, viewContainerRef);
    }
    ngAfterViewInit() {
        var _a;
        if (this.component == null && this.elementRef.nativeElement.componentName == undefined) {
            var componentViewIndex = -1;
            var component = null;
            var element = this.element;
            var FindTry = 1;
            var componentId = this.elementRef.nativeElement.getAttribute('component-id');
            if (componentId == null || componentId == '') {
                componentId = this.name.split('_')[0];
            }
            componentViewIndex = -1;
            if (componentId != null && componentId != '') {
                this.elementRef.nativeElement.__ngContext__.forEach((x, i) => { if (x != null) {
                    if (x.constructor.name.indexOf("LComponentView_" + componentId) > -1) {
                        componentViewIndex = i;
                    }
                } });
                if (componentViewIndex != -1) {
                    var componentIndex = -1;
                    this.elementRef.nativeElement.__ngContext__[componentViewIndex].forEach((x, i) => {
                        if (x != null) {
                            if (x.constructor.name == componentId) {
                                componentIndex = i;
                            }
                        }
                    });
                    if (componentIndex != -1)
                        component = this.elementRef.nativeElement.__ngContext__[componentViewIndex][componentIndex];
                }
            }
            if (component != null && !this.element.isPopulated)
                this.textDirective = new TextDirective({ element: this.element, name: this.name, target: component.constructor });
            else if (this.element) {
                while (component == null) {
                    componentViewIndex = -1;
                    if (element && element.parentElement && element.parentElement.__ngContext__) {
                        element.parentElement.__ngContext__.forEach((x, i) => { if (x != null) {
                            if (x.constructor.name.indexOf("LComponentView_") > -1) {
                                componentViewIndex = i;
                            }
                        } });
                        var component = null;
                        if (componentViewIndex != -1) {
                            element.parentElement.__ngContext__[componentViewIndex][0].__ngContext__.forEach(x => {
                                for (var item in x) {
                                    if (item == 'components') {
                                        if (x[item].constructor.name == 'Array') {
                                            component = x[item][0];
                                        }
                                    }
                                }
                            });
                        }
                    }
                    if (component == null) {
                        element = element ? element.parentElement : null;
                        FindTry = FindTry + 1;
                    }
                    if (FindTry > 20)
                        break;
                }
                if (!this.element.isPopulated)
                    this.textDirective = new TextDirective({ element: this.element, name: this.name, target: component != null ? component.constructor : null });
            }
        }
        else if (!this.element.isPopulated)
            this.textDirective = new TextDirective({ element: this.element, name: this.name, target: this.component, text: this.text });
        if (!this.element.isPopulated)
            (_a = this.textDirective) === null || _a === void 0 ? void 0 : _a.bind();
    }
    ngOnDestroy() {
        if (this.textDirective)
            this.textDirective.destroy();
    }
}
RxTextDirective.decorators = [
    { type: Directive, args: [{
                selector: '[rxText]',
            },] }
];
RxTextDirective.ctorParameters = () => [
    { type: Renderer2 },
    { type: ElementRef },
    { type: ViewContainerRef }
];
RxTextDirective.propDecorators = {
    name: [{ type: Input, args: ['rxText',] }],
    text: [{ type: Input }]
};

class RxLocalizationModule {
}
RxLocalizationModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RxPlaceholderDirective, RxTextDirective],
                exports: [RxPlaceholderDirective, RxTextDirective],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { RxLocalizationModule, RxPlaceholderDirective, RxTextDirective, BaseDirective as ɵa };
//# sourceMappingURL=rxweb-angular-localization.js.map
